<?php

namespace Drupal\publication_scheduler\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Main administration form for the Publication Scheduler module.
 */
class AdminForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'publication_scheduler_admin_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['publication_scheduler.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['convert_status_field_to_radios'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Convert the status field to radios'),
      '#default_value' => $this->setting('convert_status_field_to_radios'),
      '#description' => $this->t('If checked, the status field will be converted to radios.'),
    ];

    $form['allow_editing_created_date'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Allow editing the created date (Authored On) of nodes'),
      '#default_value' => $this->setting('allow_editing_created_date'),
      '#description' => $this->t('Ability to edit the created date of content is disabled by default by the Publication Scheduler module. The default bahaviour of the Drupal will be restored if checked. If unchecked, only users with the "allow editing of created date" permission users will be able to edit the created date of content. Administrators will always be able to edit the created date of content.'),
    ];

    $form['hide_publish_on_field_if_published_status_set'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Hide the publish on field if the published status is set'),
      '#default_value' => $this->setting('hide_publish_on_field_if_published_status_set'),
      '#description' => $this->t('If checked, the "Publish On" field will be hidden if the published status is set in content add/edit forms, meaning no scheduling.'),
    ];

    $form['hide_fields'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Hide "Authored On" and "Published On" fields by default'),
      '#default_value' => $this->setting('hide_fields'),
      '#description' => $this->t('If checked, the "Authored On" and "Published On" fields will be hidden by default (even for admins roles with permission to edit them) and a checkbox will be added to show them if needed.'),
    ];

    return parent::buildForm($form, $form_state);
  }


  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('publication_scheduler.settings')
      ->set('convert_status_field_to_radios', $form_state->getValue(['convert_status_field_to_radios']))
      ->set('allow_editing_created_date', $form_state->getValue(['allow_editing_created_date']))
      ->set('hide_publish_on_field_if_published_status_set', $form_state->getValue(['hide_publish_on_field_if_published_status_set']))
      ->set('hide_fields', $form_state->getValue(['hide_fields']))
      ->save();

    parent::submitForm($form, $form_state);
  }

  /**
   * Helper method to access the settings of this module.
   *
   * @param string $key
   *   The key of the configuration.
   *
   * @return \Drupal\Core\Config\ImmutableConfig
   *   The value of the config setting equested.
   */
  protected function setting($key) {
    return $this->configFactory->get('publication_scheduler.settings')->get($key);
  }

}
